"""ens_var module

The ens_var module provides a proxy interface to EnSight ENS_VAR instances

"""
from ansys.pyensight.core.session import Session
from ansys.pyensight.core.ensobj import ENSOBJ
from ansys.pyensight.core import ensobjlist
from typing import Any, Dict, List, Type, Union, Optional, Tuple, TYPE_CHECKING, cast

if TYPE_CHECKING:
    from ansys.api.pyensight.ensight_api import ENS_ANNOT, ENS_PALETTE, ENS_PART, ENS_SOURCE, ENS_CASE, ENS_QUERY, ENS_GROUP, ENS_TOOL, ENS_TEXTURE, ENS_VPORT, ENS_PLOTTER, ENS_POLYLINE, ENS_FRAME, ENS_PROBE, ENS_FLIPBOOK, ENS_SCENE, ENS_LPART, ENS_STATE, ens_emitterobj

class ENS_VAR(ENSOBJ):
    """This class acts as a proxy for the EnSight Python class ensight.objs.ENS_VAR

    Args:
        \*args:
            Superclass (ENSOBJ) arguments
        \**kwargs:
            Superclass (ENSOBJ) keyword arguments

    """

    def __init__(self, *args, **kwargs) -> None:
        super().__init__(*args, **kwargs)
        self._update_attr_list(self._session, self._objid)

    @classmethod
    def _update_attr_list(cls, session: 'Session', id: int) -> None:
        if hasattr(cls, 'attr_list'):
            return
        cmd = session.remote_obj(id) + '.__ids__'
        cls.attr_list = session.cmd(cmd)

    @property
    def objid(self) -> int:  # noqa: N802
        """
        Return the EnSight object proxy ID (__OBJID__).
        """
        return self._objid

    def attrgroupinfo(self, *args, **kwargs) -> Any:
        """Get information about GUI groups for object attributes

        """
        arg_obj = f"{self._remote_obj()}"
        arg_list: List[str] = []
        for arg in args:
            arg_list.append(arg.__repr__())
        for key, value in kwargs.items():
            arg_list.append(f"{key}={value.__repr__()}")
        arg_string = ",".join(arg_list)
        cmd = f"{arg_obj}.attrgroupinfo({arg_string})"
        return self._session.cmd(cmd)

    def realize(self, *args, **kwargs) -> Any:
        """Activate a stub computed variable

        """
        arg_obj = f"{self._remote_obj()}"
        arg_list: List[str] = []
        for arg in args:
            arg_list.append(arg.__repr__())
        for key, value in kwargs.items():
            arg_list.append(f"{key}={value.__repr__()}")
        arg_string = ",".join(arg_list)
        cmd = f"{arg_obj}.realize({arg_string})"
        return self._session.cmd(cmd)

    def histogram(self, *args, **kwargs) -> Any:
        """Compute the histogram of a variable

        """
        arg_obj = f"{self._remote_obj()}"
        arg_list: List[str] = []
        for arg in args:
            arg_list.append(arg.__repr__())
        for key, value in kwargs.items():
            arg_list.append(f"{key}={value.__repr__()}")
        arg_string = ",".join(arg_list)
        cmd = f"{arg_obj}.histogram({arg_string})"
        return self._session.cmd(cmd)

    def dependent_vars(self, *args, **kwargs) -> Any:
        """Add dependent temporary variable list

        """
        arg_obj = f"{self._remote_obj()}"
        arg_list: List[str] = []
        for arg in args:
            arg_list.append(arg.__repr__())
        for key, value in kwargs.items():
            arg_list.append(f"{key}={value.__repr__()}")
        arg_string = ",".join(arg_list)
        cmd = f"{arg_obj}.dependent_vars({arg_string})"
        return self._session.cmd(cmd)

    @property
    def METADATA(self) -> Dict[Any, Any]:
        """METADATA property
        
        metadata
        
        Supported operations:
            getattr
        Datatype:
            CEI Metadata, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.METADATA)
        _value = cast(Dict[Any, Any], value)
        return _value

    @property
    def metadata(self) -> Dict[Any, Any]:
        """METADATA property
        
        metadata
        
        Supported operations:
            getattr
        Datatype:
            CEI Metadata, scalar
        
        Note: both 'metadata' and 'METADATA' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.METADATA)
        _value = cast(Dict[Any, Any], value)
        return _value

    @property
    def UUID(self) -> str:
        """UUID property
        
        universal unique id
        
        Supported operations:
            getattr
        Datatype:
            String, 37 characters maximum
        
        """
        value = self.getattr(self._session.ensight.objs.enums.UUID)
        _value = cast(str, value)
        return _value

    @property
    def uuid(self) -> str:
        """UUID property
        
        universal unique id
        
        Supported operations:
            getattr
        Datatype:
            String, 37 characters maximum
        
        Note: both 'uuid' and 'UUID' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.UUID)
        _value = cast(str, value)
        return _value

    @property
    def EDIT_TARGET(self) -> int:
        """EDIT_TARGET property
        
        currently an edit target
        
        Supported operations:
            getattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.EDIT_TARGET)
        _value = cast(int, value)
        return _value

    @property
    def edit_target(self) -> int:
        """EDIT_TARGET property
        
        currently an edit target
        
        Supported operations:
            getattr
        Datatype:
            Boolean, scalar
        
        Note: both 'edit_target' and 'EDIT_TARGET' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.EDIT_TARGET)
        _value = cast(int, value)
        return _value

    @property
    def PROJECT_MASK(self) -> int:
        """PROJECT_MASK property
        
        object project mask
        
        Supported operations:
            getattr, setattr
        Datatype:
            64bit integer, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.PROJECT_MASK)
        _value = cast(int, value)
        return _value

    @PROJECT_MASK.setter
    def PROJECT_MASK(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.PROJECT_MASK, value)

    @property
    def project_mask(self) -> int:
        """PROJECT_MASK property
        
        object project mask
        
        Supported operations:
            getattr, setattr
        Datatype:
            64bit integer, scalar
        
        Note: both 'project_mask' and 'PROJECT_MASK' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.PROJECT_MASK)
        _value = cast(int, value)
        return _value

    @project_mask.setter
    def project_mask(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.PROJECT_MASK, value)

    @property
    def HANDLES_ENABLED(self) -> int:
        """Control the display and use of EnSight click and go handles for an object
        
        EnSight allows for direct interaction with many objects via click and go handles.
        The handles allow things like annotations and viewports to be moved or resized.
        They allow for the adjustment of values for clip planes and palette dynamic ranges.
        In some situations, allowing the user to directly adjust these values can be
        undesirable.  Setting this attribute to zero disables display of and interaction
        with click and go handles for the specific object instance.
        
        """
        value = self.getattr(self._session.ensight.objs.enums.HANDLES_ENABLED)
        _value = cast(int, value)
        return _value

    @HANDLES_ENABLED.setter
    def HANDLES_ENABLED(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.HANDLES_ENABLED, value)

    @property
    def handles_enabled(self) -> int:
        """Control the display and use of EnSight click and go handles for an object
        
        EnSight allows for direct interaction with many objects via click and go handles.
        The handles allow things like annotations and viewports to be moved or resized.
        They allow for the adjustment of values for clip planes and palette dynamic ranges.
        In some situations, allowing the user to directly adjust these values can be
        undesirable.  Setting this attribute to zero disables display of and interaction
        with click and go handles for the specific object instance.
        
        Note: both 'handles_enabled' and 'HANDLES_ENABLED' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.HANDLES_ENABLED)
        _value = cast(int, value)
        return _value

    @handles_enabled.setter
    def handles_enabled(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.HANDLES_ENABLED, value)

    @property
    def CFD_VAR(self) -> str:
        """CFD_VAR property
        
        CFD Type
        
        Supported operations:
            getattr
        Datatype:
            String, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.CFD_VAR)
        _value = cast(str, value)
        return _value

    @property
    def cfd_var(self) -> str:
        """CFD_VAR property
        
        CFD Type
        
        Supported operations:
            getattr
        Datatype:
            String, scalar
        
        Note: both 'cfd_var' and 'CFD_VAR' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.CFD_VAR)
        _value = cast(str, value)
        return _value

    @property
    def ENS_UNITS_LABEL(self) -> str:
        """ENS_UNITS_LABEL property
        
        Units
        
        Supported operations:
            getattr, setattr
        Datatype:
            String, 4096 characters maximum
        
        """
        value = self.getattr(self._session.ensight.objs.enums.ENS_UNITS_LABEL)
        _value = cast(str, value)
        return _value

    @ENS_UNITS_LABEL.setter
    def ENS_UNITS_LABEL(self, value: str) -> None:
        self.setattr(self._session.ensight.objs.enums.ENS_UNITS_LABEL, value)

    @property
    def ens_units_label(self) -> str:
        """ENS_UNITS_LABEL property
        
        Units
        
        Supported operations:
            getattr, setattr
        Datatype:
            String, 4096 characters maximum
        
        Note: both 'ens_units_label' and 'ENS_UNITS_LABEL' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.ENS_UNITS_LABEL)
        _value = cast(str, value)
        return _value

    @ens_units_label.setter
    def ens_units_label(self, value: str) -> None:
        self.setattr(self._session.ensight.objs.enums.ENS_UNITS_LABEL, value)

    @property
    def ENS_UNITS_DIMS(self) -> str:
        """ENS_UNITS_DIMS property
        
        Unit Dimensions
        
        Supported operations:
            getattr, setattr
        Datatype:
            String, 4096 characters maximum
        
        """
        value = self.getattr(self._session.ensight.objs.enums.ENS_UNITS_DIMS)
        _value = cast(str, value)
        return _value

    @ENS_UNITS_DIMS.setter
    def ENS_UNITS_DIMS(self, value: str) -> None:
        self.setattr(self._session.ensight.objs.enums.ENS_UNITS_DIMS, value)

    @property
    def ens_units_dims(self) -> str:
        """ENS_UNITS_DIMS property
        
        Unit Dimensions
        
        Supported operations:
            getattr, setattr
        Datatype:
            String, 4096 characters maximum
        
        Note: both 'ens_units_dims' and 'ENS_UNITS_DIMS' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.ENS_UNITS_DIMS)
        _value = cast(str, value)
        return _value

    @ens_units_dims.setter
    def ens_units_dims(self, value: str) -> None:
        self.setattr(self._session.ensight.objs.enums.ENS_UNITS_DIMS, value)

    @property
    def FEA_VAR(self) -> str:
        """FEA_VAR property
        
        FEA Type
        
        Supported operations:
            getattr
        Datatype:
            String, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.FEA_VAR)
        _value = cast(str, value)
        return _value

    @property
    def fea_var(self) -> str:
        """FEA_VAR property
        
        FEA Type
        
        Supported operations:
            getattr
        Datatype:
            String, scalar
        
        Note: both 'fea_var' and 'FEA_VAR' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.FEA_VAR)
        _value = cast(str, value)
        return _value

    @property
    def PARENT(self) -> ensobjlist:
        """PARENT property
        
        parent
        
        Supported operations:
            getattr
        Datatype:
            Object, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.PARENT)
        _value = cast(ensobjlist, value)
        return _value

    @property
    def parent(self) -> ensobjlist:
        """PARENT property
        
        parent
        
        Supported operations:
            getattr
        Datatype:
            Object, scalar
        
        Note: both 'parent' and 'PARENT' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.PARENT)
        _value = cast(ensobjlist, value)
        return _value

    @property
    def DESCRIPTION(self) -> str:
        """DESCRIPTION property
        
        Description
        
        Supported operations:
            getattr
        Datatype:
            String, 50 characters maximum
        
        """
        value = self.getattr(self._session.ensight.objs.enums.DESCRIPTION)
        _value = cast(str, value)
        return _value

    @property
    def description(self) -> str:
        """DESCRIPTION property
        
        Description
        
        Supported operations:
            getattr
        Datatype:
            String, 50 characters maximum
        
        Note: both 'description' and 'DESCRIPTION' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.DESCRIPTION)
        _value = cast(str, value)
        return _value

    @property
    def PATHNAME(self) -> str:
        """PATHNAME property
        
        full name
        
        Supported operations:
            getattr, setattr
        Datatype:
            String, 2048 characters maximum
        
        """
        value = self.getattr(self._session.ensight.objs.enums.PATHNAME)
        _value = cast(str, value)
        return _value

    @PATHNAME.setter
    def PATHNAME(self, value: str) -> None:
        self.setattr(self._session.ensight.objs.enums.PATHNAME, value)

    @property
    def pathname(self) -> str:
        """PATHNAME property
        
        full name
        
        Supported operations:
            getattr, setattr
        Datatype:
            String, 2048 characters maximum
        
        Note: both 'pathname' and 'PATHNAME' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.PATHNAME)
        _value = cast(str, value)
        return _value

    @pathname.setter
    def pathname(self, value: str) -> None:
        self.setattr(self._session.ensight.objs.enums.PATHNAME, value)

    @property
    def ACTIVE(self) -> int:
        """ACTIVE property
        
        Activated
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.ACTIVE)
        _value = cast(int, value)
        return _value

    @ACTIVE.setter
    def ACTIVE(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.ACTIVE, value)

    @property
    def active(self) -> int:
        """ACTIVE property
        
        Activated
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        Note: both 'active' and 'ACTIVE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.ACTIVE)
        _value = cast(int, value)
        return _value

    @active.setter
    def active(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.ACTIVE, value)

    @property
    def WHICH_HISTOGRAM(self) -> int:
        """WHICH_HISTOGRAM property
        
        Use dynamic histogram
        
        Supported operations:
            getattr, setattr
        Datatype:
            Integer, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.WHICH_HISTOGRAM)
        _value = cast(int, value)
        return _value

    @WHICH_HISTOGRAM.setter
    def WHICH_HISTOGRAM(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.WHICH_HISTOGRAM, value)

    @property
    def which_histogram(self) -> int:
        """WHICH_HISTOGRAM property
        
        Use dynamic histogram
        
        Supported operations:
            getattr, setattr
        Datatype:
            Integer, scalar
        
        Note: both 'which_histogram' and 'WHICH_HISTOGRAM' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.WHICH_HISTOGRAM)
        _value = cast(int, value)
        return _value

    @which_histogram.setter
    def which_histogram(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.WHICH_HISTOGRAM, value)

    @property
    def ORDER(self) -> int:
        """ORDER property
        
        Variable order
        
        Supported operations:
            getattr
        Datatype:
            Integer, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.ORDER)
        _value = cast(int, value)
        return _value

    @property
    def order(self) -> int:
        """ORDER property
        
        Variable order
        
        Supported operations:
            getattr
        Datatype:
            Integer, scalar
        
        Note: both 'order' and 'ORDER' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.ORDER)
        _value = cast(int, value)
        return _value

    @property
    def LOCATION(self) -> int:
        """LOCATION property
        
        Location
        
        Supported operations:
            getattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.ENS_VAR_CASE - Case
            * ensight.objs.enums.ENS_VAR_ELEM - Element
            * ensight.objs.enums.ENS_VAR_NODE - Node
            * ensight.objs.enums.ENS_VAR_ENOD - Point element
            * ensight.objs.enums.ENS_VAR_CONSTANT_PER_PART - Part
        
        """
        value = self.getattr(self._session.ensight.objs.enums.LOCATION)
        _value = cast(int, value)
        return _value

    @property
    def location(self) -> int:
        """LOCATION property
        
        Location
        
        Supported operations:
            getattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.ENS_VAR_CASE - Case
            * ensight.objs.enums.ENS_VAR_ELEM - Element
            * ensight.objs.enums.ENS_VAR_NODE - Node
            * ensight.objs.enums.ENS_VAR_ENOD - Point element
            * ensight.objs.enums.ENS_VAR_CONSTANT_PER_PART - Part
        
        Note: both 'location' and 'LOCATION' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.LOCATION)
        _value = cast(int, value)
        return _value

    @property
    def VARTYPE(self) -> int:
        """VARTYPE property
        
        Variable type
        
        Supported operations:
            getattr
        Datatype:
            Integer, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.VARTYPE)
        _value = cast(int, value)
        return _value

    @property
    def vartype(self) -> int:
        """VARTYPE property
        
        Variable type
        
        Supported operations:
            getattr
        Datatype:
            Integer, scalar
        
        Note: both 'vartype' and 'VARTYPE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.VARTYPE)
        _value = cast(int, value)
        return _value

    @property
    def VARTYPEENUM(self) -> int:
        """VARTYPEENUM property
        
        Type
        
        Supported operations:
            getattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.ENS_VAR_SCALAR - Scalar
            * ensight.objs.enums.ENS_VAR_VECTOR - Vector
            * ensight.objs.enums.ENS_VAR_TENSOR - Tensor
            * ensight.objs.enums.ENS_VAR_SCALAR_COMPLEX - Scalar complex
            * ensight.objs.enums.ENS_VAR_VECTOR_COMPLEX - Vector complex
            * ensight.objs.enums.ENS_VAR_CONSTANT - Constant
            * ensight.objs.enums.ENS_VAR_TIME_FUNC - Time
            * ensight.objs.enums.ENS_VAR_COORDS - Coordinates
            * ensight.objs.enums.ENS_VAR_CONSTANT_PER_PART - Constant per part
            * ensight.objs.enums.ENS_VAR_UNKNOWN - Unknown
        
        """
        value = self.getattr(self._session.ensight.objs.enums.VARTYPEENUM)
        _value = cast(int, value)
        return _value

    @property
    def vartypeenum(self) -> int:
        """VARTYPEENUM property
        
        Type
        
        Supported operations:
            getattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.ENS_VAR_SCALAR - Scalar
            * ensight.objs.enums.ENS_VAR_VECTOR - Vector
            * ensight.objs.enums.ENS_VAR_TENSOR - Tensor
            * ensight.objs.enums.ENS_VAR_SCALAR_COMPLEX - Scalar complex
            * ensight.objs.enums.ENS_VAR_VECTOR_COMPLEX - Vector complex
            * ensight.objs.enums.ENS_VAR_CONSTANT - Constant
            * ensight.objs.enums.ENS_VAR_TIME_FUNC - Time
            * ensight.objs.enums.ENS_VAR_COORDS - Coordinates
            * ensight.objs.enums.ENS_VAR_CONSTANT_PER_PART - Constant per part
            * ensight.objs.enums.ENS_VAR_UNKNOWN - Unknown
        
        Note: both 'vartypeenum' and 'VARTYPEENUM' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.VARTYPEENUM)
        _value = cast(int, value)
        return _value

    @property
    def COMPUTED(self) -> int:
        """COMPUTED property
        
        Computed
        
        Supported operations:
            getattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.COMPUTED)
        _value = cast(int, value)
        return _value

    @property
    def computed(self) -> int:
        """COMPUTED property
        
        Computed
        
        Supported operations:
            getattr
        Datatype:
            Boolean, scalar
        
        Note: both 'computed' and 'COMPUTED' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.COMPUTED)
        _value = cast(int, value)
        return _value

    @property
    def EXPRESSION(self) -> str:
        """EXPRESSION property
        
        Computed expression
        
        Supported operations:
            getattr
        Datatype:
            String, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.EXPRESSION)
        _value = cast(str, value)
        return _value

    @property
    def expression(self) -> str:
        """EXPRESSION property
        
        Computed expression
        
        Supported operations:
            getattr
        Datatype:
            String, scalar
        
        Note: both 'expression' and 'EXPRESSION' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.EXPRESSION)
        _value = cast(str, value)
        return _value

    @property
    def ID(self) -> int:
        """ID property
        
        Variable ID
        
        Supported operations:
            getattr
        Datatype:
            Integer, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.ID)
        _value = cast(int, value)
        return _value

    @property
    def id(self) -> int:
        """ID property
        
        Variable ID
        
        Supported operations:
            getattr
        Datatype:
            Integer, scalar
        
        Note: both 'id' and 'ID' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.ID)
        _value = cast(int, value)
        return _value

    @property
    def MINMAX(self) -> float:
        """MINMAX property
        
        Min/Max
        
        Supported operations:
            getattr
        Datatype:
            Float, 0 element array
        
        """
        value = self.getattr(self._session.ensight.objs.enums.MINMAX)
        _value = cast(float, value)
        return _value

    @property
    def minmax(self) -> float:
        """MINMAX property
        
        Min/Max
        
        Supported operations:
            getattr
        Datatype:
            Float, 0 element array
        
        Note: both 'minmax' and 'MINMAX' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.MINMAX)
        _value = cast(float, value)
        return _value

    @property
    def PALID(self) -> int:
        """PALID property
        
        Palette ID
        
        Supported operations:
            getattr
        Datatype:
            Integer, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.PALID)
        _value = cast(int, value)
        return _value

    @property
    def palid(self) -> int:
        """PALID property
        
        Palette ID
        
        Supported operations:
            getattr
        Datatype:
            Integer, scalar
        
        Note: both 'palid' and 'PALID' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.PALID)
        _value = cast(int, value)
        return _value

    @property
    def LEGEND(self) -> List['ENS_ANNOT']:
        """LEGEND property
        
        Legends
        
        Supported operations:
            getattr
        Datatype:
            ENS_ANNOT Legend, 0 element array
        
        """
        value = self.getattr(self._session.ensight.objs.enums.LEGEND)
        _value = cast(List['ENS_ANNOT'], value)
        return _value

    @property
    def legend(self) -> List['ENS_ANNOT']:
        """LEGEND property
        
        Legends
        
        Supported operations:
            getattr
        Datatype:
            ENS_ANNOT Legend, 0 element array
        
        Note: both 'legend' and 'LEGEND' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.LEGEND)
        _value = cast(List['ENS_ANNOT'], value)
        return _value

    @property
    def EXIST_CASE(self) -> List[int]:
        """EXIST_CASE property
        
        Exists in case
        
        Supported operations:
            getattr
        Datatype:
            Boolean, 32 element array
        
        """
        value = self.getattr(self._session.ensight.objs.enums.EXIST_CASE)
        _value = cast(List[int], value)
        return _value

    @property
    def exist_case(self) -> List[int]:
        """EXIST_CASE property
        
        Exists in case
        
        Supported operations:
            getattr
        Datatype:
            Boolean, 32 element array
        
        Note: both 'exist_case' and 'EXIST_CASE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.EXIST_CASE)
        _value = cast(List[int], value)
        return _value

    @property
    def PRIVATE(self) -> int:
        """PRIVATE property
        
        EnSight 'hidden' variable
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.PRIVATE)
        _value = cast(int, value)
        return _value

    @PRIVATE.setter
    def PRIVATE(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.PRIVATE, value)

    @property
    def private(self) -> int:
        """PRIVATE property
        
        EnSight 'hidden' variable
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        Note: both 'private' and 'PRIVATE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.PRIVATE)
        _value = cast(int, value)
        return _value

    @private.setter
    def private(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.PRIVATE, value)

    @property
    def SEQUENCE(self) -> int:
        """SEQUENCE property
        
        Recompute sequence number
        
        Supported operations:
            getattr
        Datatype:
            Integer, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.SEQUENCE)
        _value = cast(int, value)
        return _value

    @property
    def sequence(self) -> int:
        """SEQUENCE property
        
        Recompute sequence number
        
        Supported operations:
            getattr
        Datatype:
            Integer, scalar
        
        Note: both 'sequence' and 'SEQUENCE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.SEQUENCE)
        _value = cast(int, value)
        return _value

    @property
    def PALETTE(self) -> ensobjlist['ENS_PALETTE']:
        """PALETTE property
        
        Palette
        
        Supported operations:
            getattr
        Datatype:
            ENS_PALETTE Object, 0 element array
        
        """
        value = self.getattr(self._session.ensight.objs.enums.PALETTE)
        _value = cast(ensobjlist['ENS_PALETTE'], value)
        return _value

    @property
    def palette(self) -> ensobjlist['ENS_PALETTE']:
        """PALETTE property
        
        Palette
        
        Supported operations:
            getattr
        Datatype:
            ENS_PALETTE Object, 0 element array
        
        Note: both 'palette' and 'PALETTE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.PALETTE)
        _value = cast(ensobjlist['ENS_PALETTE'], value)
        return _value

    @property
    def PARTS(self) -> ensobjlist['ENS_PART']:
        """PARTS property
        
        Parts
        
        Supported operations:
            getattr
        Datatype:
            Object, 0 element array
        
        """
        value = self.getattr(self._session.ensight.objs.enums.PARTS)
        _value = cast(ensobjlist['ENS_PART'], value)
        return _value

    @property
    def parts(self) -> ensobjlist['ENS_PART']:
        """PARTS property
        
        Parts
        
        Supported operations:
            getattr
        Datatype:
            Object, 0 element array
        
        Note: both 'parts' and 'PARTS' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.PARTS)
        _value = cast(ensobjlist['ENS_PART'], value)
        return _value

    @property
    def CONSTANT_VALUE(self) -> float:
        """CONSTANT_VALUE property
        
        Constant value
        
        Supported operations:
            getattr
        Datatype:
            Float, 0 element array
        
        """
        value = self.getattr(self._session.ensight.objs.enums.CONSTANT_VALUE)
        _value = cast(float, value)
        return _value

    @property
    def constant_value(self) -> float:
        """CONSTANT_VALUE property
        
        Constant value
        
        Supported operations:
            getattr
        Datatype:
            Float, 0 element array
        
        Note: both 'constant_value' and 'CONSTANT_VALUE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.CONSTANT_VALUE)
        _value = cast(float, value)
        return _value

    @property
    def MINMAXCONST(self) -> float:
        """MINMAXCONST property
        
        Range
        
        Supported operations:
            getattr
        Datatype:
            Float, 0 element array
        
        """
        value = self.getattr(self._session.ensight.objs.enums.MINMAXCONST)
        _value = cast(float, value)
        return _value

    @property
    def minmaxconst(self) -> float:
        """MINMAXCONST property
        
        Range
        
        Supported operations:
            getattr
        Datatype:
            Float, 0 element array
        
        Note: both 'minmaxconst' and 'MINMAXCONST' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.MINMAXCONST)
        _value = cast(float, value)
        return _value

    @property
    def OVERRIDELTACTIVE(self) -> int:
        """OVERRIDELTACTIVE property
        
        Active
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.OVERRIDELTACTIVE)
        _value = cast(int, value)
        return _value

    @OVERRIDELTACTIVE.setter
    def OVERRIDELTACTIVE(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.OVERRIDELTACTIVE, value)

    @property
    def overrideltactive(self) -> int:
        """OVERRIDELTACTIVE property
        
        Active
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        Note: both 'overrideltactive' and 'OVERRIDELTACTIVE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.OVERRIDELTACTIVE)
        _value = cast(int, value)
        return _value

    @overrideltactive.setter
    def overrideltactive(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.OVERRIDELTACTIVE, value)

    @property
    def OVERRIDELTUSEABS(self) -> int:
        """OVERRIDELTUSEABS property
        
        Use abs(constant)
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.OVERRIDELTUSEABS)
        _value = cast(int, value)
        return _value

    @OVERRIDELTUSEABS.setter
    def OVERRIDELTUSEABS(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.OVERRIDELTUSEABS, value)

    @property
    def overrideltuseabs(self) -> int:
        """OVERRIDELTUSEABS property
        
        Use abs(constant)
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        Note: both 'overrideltuseabs' and 'OVERRIDELTUSEABS' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.OVERRIDELTUSEABS)
        _value = cast(int, value)
        return _value

    @overrideltuseabs.setter
    def overrideltuseabs(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.OVERRIDELTUSEABS, value)

    @property
    def OVERRIDELTMIN(self) -> float:
        """OVERRIDELTMIN property
        
        Value
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.OVERRIDELTMIN)
        _value = cast(float, value)
        return _value

    @OVERRIDELTMIN.setter
    def OVERRIDELTMIN(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.OVERRIDELTMIN, value)

    @property
    def overrideltmin(self) -> float:
        """OVERRIDELTMIN property
        
        Value
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        
        Note: both 'overrideltmin' and 'OVERRIDELTMIN' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.OVERRIDELTMIN)
        _value = cast(float, value)
        return _value

    @overrideltmin.setter
    def overrideltmin(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.OVERRIDELTMIN, value)

    @property
    def OVERRIDELTRGB(self) -> List[float]:
        """OVERRIDELTRGB property
        
        Color
        
        Supported operations:
            getattr, setattr
        Datatype:
            Color RGB, 3 element array
        Range:
            [0.0, 1.0]
        
        """
        value = self.getattr(self._session.ensight.objs.enums.OVERRIDELTRGB)
        _value = cast(List[float], value)
        return _value

    @OVERRIDELTRGB.setter
    def OVERRIDELTRGB(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.OVERRIDELTRGB, value)

    @property
    def overrideltrgb(self) -> List[float]:
        """OVERRIDELTRGB property
        
        Color
        
        Supported operations:
            getattr, setattr
        Datatype:
            Color RGB, 3 element array
        Range:
            [0.0, 1.0]
        
        Note: both 'overrideltrgb' and 'OVERRIDELTRGB' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.OVERRIDELTRGB)
        _value = cast(List[float], value)
        return _value

    @overrideltrgb.setter
    def overrideltrgb(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.OVERRIDELTRGB, value)

    @property
    def OVERRIDEGTACTIVE(self) -> int:
        """OVERRIDEGTACTIVE property
        
        Active
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.OVERRIDEGTACTIVE)
        _value = cast(int, value)
        return _value

    @OVERRIDEGTACTIVE.setter
    def OVERRIDEGTACTIVE(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.OVERRIDEGTACTIVE, value)

    @property
    def overridegtactive(self) -> int:
        """OVERRIDEGTACTIVE property
        
        Active
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        Note: both 'overridegtactive' and 'OVERRIDEGTACTIVE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.OVERRIDEGTACTIVE)
        _value = cast(int, value)
        return _value

    @overridegtactive.setter
    def overridegtactive(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.OVERRIDEGTACTIVE, value)

    @property
    def OVERRIDEGTUSEABS(self) -> int:
        """OVERRIDEGTUSEABS property
        
        Use abs(constant)
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.OVERRIDEGTUSEABS)
        _value = cast(int, value)
        return _value

    @OVERRIDEGTUSEABS.setter
    def OVERRIDEGTUSEABS(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.OVERRIDEGTUSEABS, value)

    @property
    def overridegtuseabs(self) -> int:
        """OVERRIDEGTUSEABS property
        
        Use abs(constant)
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        Note: both 'overridegtuseabs' and 'OVERRIDEGTUSEABS' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.OVERRIDEGTUSEABS)
        _value = cast(int, value)
        return _value

    @overridegtuseabs.setter
    def overridegtuseabs(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.OVERRIDEGTUSEABS, value)

    @property
    def OVERRIDEGTMIN(self) -> float:
        """OVERRIDEGTMIN property
        
        Value
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.OVERRIDEGTMIN)
        _value = cast(float, value)
        return _value

    @OVERRIDEGTMIN.setter
    def OVERRIDEGTMIN(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.OVERRIDEGTMIN, value)

    @property
    def overridegtmin(self) -> float:
        """OVERRIDEGTMIN property
        
        Value
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        
        Note: both 'overridegtmin' and 'OVERRIDEGTMIN' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.OVERRIDEGTMIN)
        _value = cast(float, value)
        return _value

    @overridegtmin.setter
    def overridegtmin(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.OVERRIDEGTMIN, value)

    @property
    def OVERRIDEGTRGB(self) -> List[float]:
        """OVERRIDEGTRGB property
        
        Color
        
        Supported operations:
            getattr, setattr
        Datatype:
            Color RGB, 3 element array
        Range:
            [0.0, 1.0]
        
        """
        value = self.getattr(self._session.ensight.objs.enums.OVERRIDEGTRGB)
        _value = cast(List[float], value)
        return _value

    @OVERRIDEGTRGB.setter
    def OVERRIDEGTRGB(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.OVERRIDEGTRGB, value)

    @property
    def overridegtrgb(self) -> List[float]:
        """OVERRIDEGTRGB property
        
        Color
        
        Supported operations:
            getattr, setattr
        Datatype:
            Color RGB, 3 element array
        Range:
            [0.0, 1.0]
        
        Note: both 'overridegtrgb' and 'OVERRIDEGTRGB' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.OVERRIDEGTRGB)
        _value = cast(List[float], value)
        return _value

    @overridegtrgb.setter
    def overridegtrgb(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.OVERRIDEGTRGB, value)

    @property
    def OVERRIDERANGEACTIVE(self) -> int:
        """OVERRIDERANGEACTIVE property
        
        Active
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.OVERRIDERANGEACTIVE)
        _value = cast(int, value)
        return _value

    @OVERRIDERANGEACTIVE.setter
    def OVERRIDERANGEACTIVE(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.OVERRIDERANGEACTIVE, value)

    @property
    def overriderangeactive(self) -> int:
        """OVERRIDERANGEACTIVE property
        
        Active
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        Note: both 'overriderangeactive' and 'OVERRIDERANGEACTIVE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.OVERRIDERANGEACTIVE)
        _value = cast(int, value)
        return _value

    @overriderangeactive.setter
    def overriderangeactive(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.OVERRIDERANGEACTIVE, value)

    @property
    def OVERRIDERANGEUSEABS(self) -> int:
        """OVERRIDERANGEUSEABS property
        
        Use abs(constant)
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.OVERRIDERANGEUSEABS)
        _value = cast(int, value)
        return _value

    @OVERRIDERANGEUSEABS.setter
    def OVERRIDERANGEUSEABS(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.OVERRIDERANGEUSEABS, value)

    @property
    def overriderangeuseabs(self) -> int:
        """OVERRIDERANGEUSEABS property
        
        Use abs(constant)
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        Note: both 'overriderangeuseabs' and 'OVERRIDERANGEUSEABS' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.OVERRIDERANGEUSEABS)
        _value = cast(int, value)
        return _value

    @overriderangeuseabs.setter
    def overriderangeuseabs(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.OVERRIDERANGEUSEABS, value)

    @property
    def OVERRIDERANGEMIN(self) -> float:
        """OVERRIDERANGEMIN property
        
        Min Value
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.OVERRIDERANGEMIN)
        _value = cast(float, value)
        return _value

    @OVERRIDERANGEMIN.setter
    def OVERRIDERANGEMIN(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.OVERRIDERANGEMIN, value)

    @property
    def overriderangemin(self) -> float:
        """OVERRIDERANGEMIN property
        
        Min Value
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        
        Note: both 'overriderangemin' and 'OVERRIDERANGEMIN' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.OVERRIDERANGEMIN)
        _value = cast(float, value)
        return _value

    @overriderangemin.setter
    def overriderangemin(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.OVERRIDERANGEMIN, value)

    @property
    def OVERRIDERANGEMAX(self) -> float:
        """OVERRIDERANGEMAX property
        
        Max Value
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.OVERRIDERANGEMAX)
        _value = cast(float, value)
        return _value

    @OVERRIDERANGEMAX.setter
    def OVERRIDERANGEMAX(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.OVERRIDERANGEMAX, value)

    @property
    def overriderangemax(self) -> float:
        """OVERRIDERANGEMAX property
        
        Max Value
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        
        Note: both 'overriderangemax' and 'OVERRIDERANGEMAX' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.OVERRIDERANGEMAX)
        _value = cast(float, value)
        return _value

    @overriderangemax.setter
    def overriderangemax(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.OVERRIDERANGEMAX, value)

    @property
    def OVERRIDERANGERGB(self) -> List[float]:
        """OVERRIDERANGERGB property
        
        Color
        
        Supported operations:
            getattr, setattr
        Datatype:
            Color RGB, 3 element array
        Range:
            [0.0, 1.0]
        
        """
        value = self.getattr(self._session.ensight.objs.enums.OVERRIDERANGERGB)
        _value = cast(List[float], value)
        return _value

    @OVERRIDERANGERGB.setter
    def OVERRIDERANGERGB(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.OVERRIDERANGERGB, value)

    @property
    def overriderangergb(self) -> List[float]:
        """OVERRIDERANGERGB property
        
        Color
        
        Supported operations:
            getattr, setattr
        Datatype:
            Color RGB, 3 element array
        Range:
            [0.0, 1.0]
        
        Note: both 'overriderangergb' and 'OVERRIDERANGERGB' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.OVERRIDERANGERGB)
        _value = cast(List[float], value)
        return _value

    @overriderangergb.setter
    def overriderangergb(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.OVERRIDERANGERGB, value)



"""ens_lightsource module

The ens_lightsource module provides a proxy interface to EnSight ENS_LIGHTSOURCE instances

"""
from ansys.pyensight.core.session import Session
from ansys.pyensight.core.ensobj import ENSOBJ
from ansys.pyensight.core import ensobjlist
from typing import Any, Dict, List, Type, Union, Optional, Tuple, TYPE_CHECKING, cast

if TYPE_CHECKING:
    from ansys.api.pyensight.ensight_api import ENS_VAR, ENS_ANNOT, ENS_PALETTE, ENS_PART, ENS_SOURCE, ENS_CASE, ENS_QUERY, ENS_GROUP, ENS_TOOL, ENS_TEXTURE, ENS_VPORT, ENS_PLOTTER, ENS_POLYLINE, ENS_FRAME, ENS_PROBE, ENS_FLIPBOOK, ENS_SCENE, ENS_LPART, ENS_STATE, ens_emitterobj

class ENS_LIGHTSOURCE(ENSOBJ):
    """This class acts as a proxy for the EnSight Python class ensight.objs.ENS_LIGHTSOURCE

    Args:
        \*args:
            Superclass (ENSOBJ) arguments
        \**kwargs:
            Superclass (ENSOBJ) keyword arguments

    """

    def __init__(self, *args, **kwargs) -> None:
        super().__init__(*args, **kwargs)
        self._update_attr_list(self._session, self._objid)

    @classmethod
    def _update_attr_list(cls, session: 'Session', id: int) -> None:
        if hasattr(cls, 'attr_list'):
            return
        cmd = session.remote_obj(id) + '.__ids__'
        cls.attr_list = session.cmd(cmd)

    @property
    def objid(self) -> int:  # noqa: N802
        """
        Return the EnSight object proxy ID (__OBJID__).
        """
        return self._objid

    def attrgroupinfo(self, *args, **kwargs) -> Any:
        """Get information about GUI groups for object attributes

        """
        arg_obj = f"{self._remote_obj()}"
        arg_list: List[str] = []
        for arg in args:
            arg_list.append(arg.__repr__())
        for key, value in kwargs.items():
            arg_list.append(f"{key}={value.__repr__()}")
        arg_string = ",".join(arg_list)
        cmd = f"{arg_obj}.attrgroupinfo({arg_string})"
        return self._session.cmd(cmd)

    def set_preset(self, *args, **kwargs) -> Any:
        """Set lighting preset
        
        Set up all light sources according to the specified predefined lighting scheme.
        
        Args:
            preset_name:
                The name of the preset to apply.
        
                * 'Three-point lighting' - A typical three-point lighting setup with one key light, one fill light and one back light
                * 'Top lighting' - Key light from the top
                * 'Back lighting' - Key light from the back
                * 'Spot lighting' - A spot light as key light from the right side

        """
        arg_obj = f"{self._remote_obj()}"
        arg_list: List[str] = []
        for arg in args:
            arg_list.append(arg.__repr__())
        for key, value in kwargs.items():
            arg_list.append(f"{key}={value.__repr__()}")
        arg_string = ",".join(arg_list)
        cmd = f"{arg_obj}.set_preset({arg_string})"
        return self._session.cmd(cmd)

    @property
    def METADATA(self) -> Dict[Any, Any]:
        """METADATA property
        
        metadata
        
        Supported operations:
            getattr
        Datatype:
            CEI Metadata, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.METADATA)
        _value = cast(Dict[Any, Any], value)
        return _value

    @property
    def metadata(self) -> Dict[Any, Any]:
        """METADATA property
        
        metadata
        
        Supported operations:
            getattr
        Datatype:
            CEI Metadata, scalar
        
        Note: both 'metadata' and 'METADATA' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.METADATA)
        _value = cast(Dict[Any, Any], value)
        return _value

    @property
    def UUID(self) -> str:
        """UUID property
        
        universal unique id
        
        Supported operations:
            getattr
        Datatype:
            String, 37 characters maximum
        
        """
        value = self.getattr(self._session.ensight.objs.enums.UUID)
        _value = cast(str, value)
        return _value

    @property
    def uuid(self) -> str:
        """UUID property
        
        universal unique id
        
        Supported operations:
            getattr
        Datatype:
            String, 37 characters maximum
        
        Note: both 'uuid' and 'UUID' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.UUID)
        _value = cast(str, value)
        return _value

    @property
    def EDIT_TARGET(self) -> int:
        """EDIT_TARGET property
        
        currently an edit target
        
        Supported operations:
            getattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.EDIT_TARGET)
        _value = cast(int, value)
        return _value

    @property
    def edit_target(self) -> int:
        """EDIT_TARGET property
        
        currently an edit target
        
        Supported operations:
            getattr
        Datatype:
            Boolean, scalar
        
        Note: both 'edit_target' and 'EDIT_TARGET' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.EDIT_TARGET)
        _value = cast(int, value)
        return _value

    @property
    def PROJECT_MASK(self) -> int:
        """PROJECT_MASK property
        
        object project mask
        
        Supported operations:
            getattr, setattr
        Datatype:
            64bit integer, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.PROJECT_MASK)
        _value = cast(int, value)
        return _value

    @PROJECT_MASK.setter
    def PROJECT_MASK(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.PROJECT_MASK, value)

    @property
    def project_mask(self) -> int:
        """PROJECT_MASK property
        
        object project mask
        
        Supported operations:
            getattr, setattr
        Datatype:
            64bit integer, scalar
        
        Note: both 'project_mask' and 'PROJECT_MASK' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.PROJECT_MASK)
        _value = cast(int, value)
        return _value

    @project_mask.setter
    def project_mask(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.PROJECT_MASK, value)

    @property
    def HANDLES_ENABLED(self) -> int:
        """Control the display and use of EnSight click and go handles for an object
        
        EnSight allows for direct interaction with many objects via click and go handles.
        The handles allow things like annotations and viewports to be moved or resized.
        They allow for the adjustment of values for clip planes and palette dynamic ranges.
        In some situations, allowing the user to directly adjust these values can be
        undesirable.  Setting this attribute to zero disables display of and interaction
        with click and go handles for the specific object instance.
        
        """
        value = self.getattr(self._session.ensight.objs.enums.HANDLES_ENABLED)
        _value = cast(int, value)
        return _value

    @HANDLES_ENABLED.setter
    def HANDLES_ENABLED(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.HANDLES_ENABLED, value)

    @property
    def handles_enabled(self) -> int:
        """Control the display and use of EnSight click and go handles for an object
        
        EnSight allows for direct interaction with many objects via click and go handles.
        The handles allow things like annotations and viewports to be moved or resized.
        They allow for the adjustment of values for clip planes and palette dynamic ranges.
        In some situations, allowing the user to directly adjust these values can be
        undesirable.  Setting this attribute to zero disables display of and interaction
        with click and go handles for the specific object instance.
        
        Note: both 'handles_enabled' and 'HANDLES_ENABLED' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.HANDLES_ENABLED)
        _value = cast(int, value)
        return _value

    @handles_enabled.setter
    def handles_enabled(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.HANDLES_ENABLED, value)

    @property
    def DESCRIPTION(self) -> str:
        """DESCRIPTION property
        
        Description
        
        Supported operations:
            getattr
        Datatype:
            String, 80 characters maximum
        
        """
        value = self.getattr(self._session.ensight.objs.enums.DESCRIPTION)
        _value = cast(str, value)
        return _value

    @property
    def description(self) -> str:
        """DESCRIPTION property
        
        Description
        
        Supported operations:
            getattr
        Datatype:
            String, 80 characters maximum
        
        Note: both 'description' and 'DESCRIPTION' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.DESCRIPTION)
        _value = cast(str, value)
        return _value

    @property
    def SELECTED(self) -> int:
        """SELECTED property
        
        light source selected
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.SELECTED)
        _value = cast(int, value)
        return _value

    @SELECTED.setter
    def SELECTED(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.SELECTED, value)

    @property
    def selected(self) -> int:
        """SELECTED property
        
        light source selected
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        Note: both 'selected' and 'SELECTED' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.SELECTED)
        _value = cast(int, value)
        return _value

    @selected.setter
    def selected(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.SELECTED, value)

    @property
    def VISIBLE(self) -> int:
        """VISIBLE property
        
        light source visible
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.VISIBLE)
        _value = cast(int, value)
        return _value

    @VISIBLE.setter
    def VISIBLE(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.VISIBLE, value)

    @property
    def visible(self) -> int:
        """VISIBLE property
        
        light source visible
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        Note: both 'visible' and 'VISIBLE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.VISIBLE)
        _value = cast(int, value)
        return _value

    @visible.setter
    def visible(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.VISIBLE, value)

    @property
    def ACTIVE(self) -> int:
        """ACTIVE property
        
        light source active
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.ACTIVE)
        _value = cast(int, value)
        return _value

    @ACTIVE.setter
    def ACTIVE(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.ACTIVE, value)

    @property
    def active(self) -> int:
        """ACTIVE property
        
        light source active
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        Note: both 'active' and 'ACTIVE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.ACTIVE)
        _value = cast(int, value)
        return _value

    @active.setter
    def active(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.ACTIVE, value)

    @property
    def INDEX(self) -> int:
        """INDEX property
        
        light index
        
        Supported operations:
            getattr
        Datatype:
            Integer, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.INDEX)
        _value = cast(int, value)
        return _value

    @property
    def index(self) -> int:
        """INDEX property
        
        light index
        
        Supported operations:
            getattr
        Datatype:
            Integer, scalar
        
        Note: both 'index' and 'INDEX' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.INDEX)
        _value = cast(int, value)
        return _value

    @property
    def TRANSFORM_WITH_MODEL(self) -> int:
        """TRANSFORM_WITH_MODEL property
        
        light moves with model
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.TRANSFORM_WITH_MODEL)
        _value = cast(int, value)
        return _value

    @TRANSFORM_WITH_MODEL.setter
    def TRANSFORM_WITH_MODEL(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.TRANSFORM_WITH_MODEL, value)

    @property
    def transform_with_model(self) -> int:
        """TRANSFORM_WITH_MODEL property
        
        light moves with model
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        Note: both 'transform_with_model' and 'TRANSFORM_WITH_MODEL' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.TRANSFORM_WITH_MODEL)
        _value = cast(int, value)
        return _value

    @transform_with_model.setter
    def transform_with_model(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.TRANSFORM_WITH_MODEL, value)

    @property
    def LIGHT_TYPE(self) -> int:
        """LIGHT_TYPE property
        
        light type
        
        Supported operations:
            getattr, setattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.LIGHT_DIRECTIONAL - directional
            * ensight.objs.enums.LIGHT_SPOT - spot
            * ensight.objs.enums.LIGHT_POINT - point
            * ensight.objs.enums.LIGHT_AREA_QUAD - quad
            * ensight.objs.enums.LIGHT_AT_CAMERA - directional
            * ensight.objs.enums.LIGHT_AREA_ENV - env
        
        """
        value = self.getattr(self._session.ensight.objs.enums.LIGHT_TYPE)
        _value = cast(int, value)
        return _value

    @LIGHT_TYPE.setter
    def LIGHT_TYPE(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.LIGHT_TYPE, value)

    @property
    def light_type(self) -> int:
        """LIGHT_TYPE property
        
        light type
        
        Supported operations:
            getattr, setattr
        Datatype:
            Enum, scalar
        Enums:
            * ensight.objs.enums.LIGHT_DIRECTIONAL - directional
            * ensight.objs.enums.LIGHT_SPOT - spot
            * ensight.objs.enums.LIGHT_POINT - point
            * ensight.objs.enums.LIGHT_AREA_QUAD - quad
            * ensight.objs.enums.LIGHT_AT_CAMERA - directional
            * ensight.objs.enums.LIGHT_AREA_ENV - env
        
        Note: both 'light_type' and 'LIGHT_TYPE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.LIGHT_TYPE)
        _value = cast(int, value)
        return _value

    @light_type.setter
    def light_type(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.LIGHT_TYPE, value)

    @property
    def DIRECTION(self) -> List[float]:
        """DIRECTION property
        
        light source direction
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, 3 element array
        Range:
            [-1.0, 1.0]
        
        """
        value = self.getattr(self._session.ensight.objs.enums.DIRECTION)
        _value = cast(List[float], value)
        return _value

    @DIRECTION.setter
    def DIRECTION(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.DIRECTION, value)

    @property
    def direction(self) -> List[float]:
        """DIRECTION property
        
        light source direction
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, 3 element array
        Range:
            [-1.0, 1.0]
        
        Note: both 'direction' and 'DIRECTION' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.DIRECTION)
        _value = cast(List[float], value)
        return _value

    @direction.setter
    def direction(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.DIRECTION, value)

    @property
    def LOCATION(self) -> List[float]:
        """LOCATION property
        
        light source origin
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, 3 element array
        
        """
        value = self.getattr(self._session.ensight.objs.enums.LOCATION)
        _value = cast(List[float], value)
        return _value

    @LOCATION.setter
    def LOCATION(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.LOCATION, value)

    @property
    def location(self) -> List[float]:
        """LOCATION property
        
        light source origin
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, 3 element array
        
        Note: both 'location' and 'LOCATION' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.LOCATION)
        _value = cast(List[float], value)
        return _value

    @location.setter
    def location(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.LOCATION, value)

    @property
    def CENTROID(self) -> List[float]:
        """CENTROID property
        
        light source centroid
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, 3 element array
        
        """
        value = self.getattr(self._session.ensight.objs.enums.CENTROID)
        _value = cast(List[float], value)
        return _value

    @CENTROID.setter
    def CENTROID(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.CENTROID, value)

    @property
    def centroid(self) -> List[float]:
        """CENTROID property
        
        light source centroid
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, 3 element array
        
        Note: both 'centroid' and 'CENTROID' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.CENTROID)
        _value = cast(List[float], value)
        return _value

    @centroid.setter
    def centroid(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.CENTROID, value)

    @property
    def SPOT_ANGLE(self) -> float:
        """SPOT_ANGLE property
        
        spotlight source angle
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        Range:
            [0.0, 180.0]
        
        """
        value = self.getattr(self._session.ensight.objs.enums.SPOT_ANGLE)
        _value = cast(float, value)
        return _value

    @SPOT_ANGLE.setter
    def SPOT_ANGLE(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.SPOT_ANGLE, value)

    @property
    def spot_angle(self) -> float:
        """SPOT_ANGLE property
        
        spotlight source angle
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        Range:
            [0.0, 180.0]
        
        Note: both 'spot_angle' and 'SPOT_ANGLE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.SPOT_ANGLE)
        _value = cast(float, value)
        return _value

    @spot_angle.setter
    def spot_angle(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.SPOT_ANGLE, value)

    @property
    def SPOT_FALLOFF(self) -> float:
        """SPOT_FALLOFF property
        
        spotlight source falloff
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        Range:
            [0.0, 1.0]
        
        """
        value = self.getattr(self._session.ensight.objs.enums.SPOT_FALLOFF)
        _value = cast(float, value)
        return _value

    @SPOT_FALLOFF.setter
    def SPOT_FALLOFF(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.SPOT_FALLOFF, value)

    @property
    def spot_falloff(self) -> float:
        """SPOT_FALLOFF property
        
        spotlight source falloff
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        Range:
            [0.0, 1.0]
        
        Note: both 'spot_falloff' and 'SPOT_FALLOFF' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.SPOT_FALLOFF)
        _value = cast(float, value)
        return _value

    @spot_falloff.setter
    def spot_falloff(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.SPOT_FALLOFF, value)

    @property
    def INTENSITY(self) -> float:
        """INTENSITY property
        
        light source intensity
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        Range:
            [0.0, 1.0]
        
        """
        value = self.getattr(self._session.ensight.objs.enums.INTENSITY)
        _value = cast(float, value)
        return _value

    @INTENSITY.setter
    def INTENSITY(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.INTENSITY, value)

    @property
    def intensity(self) -> float:
        """INTENSITY property
        
        light source intensity
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        Range:
            [0.0, 1.0]
        
        Note: both 'intensity' and 'INTENSITY' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.INTENSITY)
        _value = cast(float, value)
        return _value

    @intensity.setter
    def intensity(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.INTENSITY, value)

    @property
    def COLOR(self) -> List[float]:
        """COLOR property
        
        light source color
        
        Supported operations:
            getattr, setattr
        Datatype:
            Color RGB, 3 element array
        Range:
            [0.0, 1.0]
        
        """
        value = self.getattr(self._session.ensight.objs.enums.COLOR)
        _value = cast(List[float], value)
        return _value

    @COLOR.setter
    def COLOR(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.COLOR, value)

    @property
    def color(self) -> List[float]:
        """COLOR property
        
        light source color
        
        Supported operations:
            getattr, setattr
        Datatype:
            Color RGB, 3 element array
        Range:
            [0.0, 1.0]
        
        Note: both 'color' and 'COLOR' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.COLOR)
        _value = cast(List[float], value)
        return _value

    @color.setter
    def color(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.COLOR, value)

    @property
    def CASTS_SHADOWS(self) -> int:
        """CASTS_SHADOWS property
        
        light casts shadows
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.CASTS_SHADOWS)
        _value = cast(int, value)
        return _value

    @CASTS_SHADOWS.setter
    def CASTS_SHADOWS(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.CASTS_SHADOWS, value)

    @property
    def casts_shadows(self) -> int:
        """CASTS_SHADOWS property
        
        light casts shadows
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        Note: both 'casts_shadows' and 'CASTS_SHADOWS' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.CASTS_SHADOWS)
        _value = cast(int, value)
        return _value

    @casts_shadows.setter
    def casts_shadows(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.CASTS_SHADOWS, value)

    @property
    def ICON_SIZE(self) -> float:
        """ICON_SIZE property
        
        light source icon size
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.ICON_SIZE)
        _value = cast(float, value)
        return _value

    @ICON_SIZE.setter
    def ICON_SIZE(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.ICON_SIZE, value)

    @property
    def icon_size(self) -> float:
        """ICON_SIZE property
        
        light source icon size
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        
        Note: both 'icon_size' and 'ICON_SIZE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.ICON_SIZE)
        _value = cast(float, value)
        return _value

    @icon_size.setter
    def icon_size(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.ICON_SIZE, value)

    @property
    def RAY_END(self) -> List[float]:
        """RAY_END property
        
        light source directional intersection
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, 3 element array
        
        """
        value = self.getattr(self._session.ensight.objs.enums.RAY_END)
        _value = cast(List[float], value)
        return _value

    @RAY_END.setter
    def RAY_END(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.RAY_END, value)

    @property
    def ray_end(self) -> List[float]:
        """RAY_END property
        
        light source directional intersection
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, 3 element array
        
        Note: both 'ray_end' and 'RAY_END' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.RAY_END)
        _value = cast(List[float], value)
        return _value

    @ray_end.setter
    def ray_end(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.RAY_END, value)

    @property
    def LOCK_DIRECTION(self) -> int:
        """LOCK_DIRECTION property
        
        light lock direction
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.LOCK_DIRECTION)
        _value = cast(int, value)
        return _value

    @LOCK_DIRECTION.setter
    def LOCK_DIRECTION(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.LOCK_DIRECTION, value)

    @property
    def lock_direction(self) -> int:
        """LOCK_DIRECTION property
        
        light lock direction
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        Note: both 'lock_direction' and 'LOCK_DIRECTION' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.LOCK_DIRECTION)
        _value = cast(int, value)
        return _value

    @lock_direction.setter
    def lock_direction(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.LOCK_DIRECTION, value)

    @property
    def LIGHT_QUAD_XDIR(self) -> List[float]:
        """LIGHT_QUAD_XDIR property
        
        quad shape's x-axis in world for quad/environment light
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, 3 element array
        
        """
        value = self.getattr(self._session.ensight.objs.enums.LIGHT_QUAD_XDIR)
        _value = cast(List[float], value)
        return _value

    @LIGHT_QUAD_XDIR.setter
    def LIGHT_QUAD_XDIR(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.LIGHT_QUAD_XDIR, value)

    @property
    def light_quad_xdir(self) -> List[float]:
        """LIGHT_QUAD_XDIR property
        
        quad shape's x-axis in world for quad/environment light
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, 3 element array
        
        Note: both 'light_quad_xdir' and 'LIGHT_QUAD_XDIR' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.LIGHT_QUAD_XDIR)
        _value = cast(List[float], value)
        return _value

    @light_quad_xdir.setter
    def light_quad_xdir(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.LIGHT_QUAD_XDIR, value)

    @property
    def LIGHT_QUAD_SIZE(self) -> List[float]:
        """LIGHT_QUAD_SIZE property
        
        quad shape's width/height for quad/environment light
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, 2 element array
        
        """
        value = self.getattr(self._session.ensight.objs.enums.LIGHT_QUAD_SIZE)
        _value = cast(List[float], value)
        return _value

    @LIGHT_QUAD_SIZE.setter
    def LIGHT_QUAD_SIZE(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.LIGHT_QUAD_SIZE, value)

    @property
    def light_quad_size(self) -> List[float]:
        """LIGHT_QUAD_SIZE property
        
        quad shape's width/height for quad/environment light
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, 2 element array
        
        Note: both 'light_quad_size' and 'LIGHT_QUAD_SIZE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.LIGHT_QUAD_SIZE)
        _value = cast(List[float], value)
        return _value

    @light_quad_size.setter
    def light_quad_size(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.LIGHT_QUAD_SIZE, value)

    @property
    def LIGHT_ENV_TEXNUM(self) -> int:
        """LIGHT_ENV_TEXNUM property
        
        for environment light: index of HDR image list
        
        Supported operations:
            getattr, setattr
        Datatype:
            Integer, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.LIGHT_ENV_TEXNUM)
        _value = cast(int, value)
        return _value

    @LIGHT_ENV_TEXNUM.setter
    def LIGHT_ENV_TEXNUM(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.LIGHT_ENV_TEXNUM, value)

    @property
    def light_env_texnum(self) -> int:
        """LIGHT_ENV_TEXNUM property
        
        for environment light: index of HDR image list
        
        Supported operations:
            getattr, setattr
        Datatype:
            Integer, scalar
        
        Note: both 'light_env_texnum' and 'LIGHT_ENV_TEXNUM' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.LIGHT_ENV_TEXNUM)
        _value = cast(int, value)
        return _value

    @light_env_texnum.setter
    def light_env_texnum(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.LIGHT_ENV_TEXNUM, value)

    @property
    def PRESETS(self) -> object:
        """PRESETS property
        
        preset lighting names
        
        Supported operations:
            getattr
        Datatype:
            EnSight Object, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.PRESETS)
        _value = cast(object, value)
        return _value

    @property
    def presets(self) -> object:
        """PRESETS property
        
        preset lighting names
        
        Supported operations:
            getattr
        Datatype:
            EnSight Object, scalar
        
        Note: both 'presets' and 'PRESETS' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.PRESETS)
        _value = cast(object, value)
        return _value



"""ens_flipbook module

The ens_flipbook module provides a proxy interface to EnSight ENS_FLIPBOOK instances

"""
from ansys.pyensight.core.session import Session
from ansys.pyensight.core.ensobj import ENSOBJ
from ansys.pyensight.core import ensobjlist
from typing import Any, Dict, List, Type, Union, Optional, Tuple, TYPE_CHECKING, cast

if TYPE_CHECKING:
    from ansys.api.pyensight.ensight_api import ENS_VAR, ENS_ANNOT, ENS_PALETTE, ENS_PART, ENS_SOURCE, ENS_CASE, ENS_QUERY, ENS_GROUP, ENS_TOOL, ENS_TEXTURE, ENS_VPORT, ENS_PLOTTER, ENS_POLYLINE, ENS_FRAME, ENS_PROBE, ENS_SCENE, ENS_LPART, ENS_STATE, ens_emitterobj

class ENS_FLIPBOOK(ENSOBJ):
    """This class acts as a proxy for the EnSight Python class ensight.objs.ENS_FLIPBOOK

    Args:
        \*args:
            Superclass (ENSOBJ) arguments
        \**kwargs:
            Superclass (ENSOBJ) keyword arguments

    """

    def __init__(self, *args, **kwargs) -> None:
        super().__init__(*args, **kwargs)
        self._update_attr_list(self._session, self._objid)

    @classmethod
    def _update_attr_list(cls, session: 'Session', id: int) -> None:
        if hasattr(cls, 'attr_list'):
            return
        cmd = session.remote_obj(id) + '.__ids__'
        cls.attr_list = session.cmd(cmd)

    @property
    def objid(self) -> int:  # noqa: N802
        """
        Return the EnSight object proxy ID (__OBJID__).
        """
        return self._objid

    def attrgroupinfo(self, *args, **kwargs) -> Any:
        """Get information about GUI groups for object attributes

        """
        arg_obj = f"{self._remote_obj()}"
        arg_list: List[str] = []
        for arg in args:
            arg_list.append(arg.__repr__())
        for key, value in kwargs.items():
            arg_list.append(f"{key}={value.__repr__()}")
        arg_string = ",".join(arg_list)
        cmd = f"{arg_obj}.attrgroupinfo({arg_string})"
        return self._session.cmd(cmd)

    def begin(self, *args, **kwargs) -> Any:
        """Begin flipbook creation

        """
        arg_obj = f"{self._remote_obj()}"
        arg_list: List[str] = []
        for arg in args:
            arg_list.append(arg.__repr__())
        for key, value in kwargs.items():
            arg_list.append(f"{key}={value.__repr__()}")
        arg_string = ",".join(arg_list)
        cmd = f"{arg_obj}.begin({arg_string})"
        return self._session.cmd(cmd)

    def end(self, *args, **kwargs) -> Any:
        """End flipbook creation

        """
        arg_obj = f"{self._remote_obj()}"
        arg_list: List[str] = []
        for arg in args:
            arg_list.append(arg.__repr__())
        for key, value in kwargs.items():
            arg_list.append(f"{key}={value.__repr__()}")
        arg_string = ",".join(arg_list)
        cmd = f"{arg_obj}.end({arg_string})"
        return self._session.cmd(cmd)

    def savepage(self, *args, **kwargs) -> Any:
        """Save a flipbook page

        """
        arg_obj = f"{self._remote_obj()}"
        arg_list: List[str] = []
        for arg in args:
            arg_list.append(arg.__repr__())
        for key, value in kwargs.items():
            arg_list.append(f"{key}={value.__repr__()}")
        arg_string = ",".join(arg_list)
        cmd = f"{arg_obj}.savepage({arg_string})"
        return self._session.cmd(cmd)

    @property
    def METADATA(self) -> Dict[Any, Any]:
        """METADATA property
        
        metadata
        
        Supported operations:
            getattr
        Datatype:
            CEI Metadata, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.METADATA)
        _value = cast(Dict[Any, Any], value)
        return _value

    @property
    def metadata(self) -> Dict[Any, Any]:
        """METADATA property
        
        metadata
        
        Supported operations:
            getattr
        Datatype:
            CEI Metadata, scalar
        
        Note: both 'metadata' and 'METADATA' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.METADATA)
        _value = cast(Dict[Any, Any], value)
        return _value

    @property
    def UUID(self) -> str:
        """UUID property
        
        universal unique id
        
        Supported operations:
            getattr
        Datatype:
            String, 37 characters maximum
        
        """
        value = self.getattr(self._session.ensight.objs.enums.UUID)
        _value = cast(str, value)
        return _value

    @property
    def uuid(self) -> str:
        """UUID property
        
        universal unique id
        
        Supported operations:
            getattr
        Datatype:
            String, 37 characters maximum
        
        Note: both 'uuid' and 'UUID' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.UUID)
        _value = cast(str, value)
        return _value

    @property
    def EDIT_TARGET(self) -> int:
        """EDIT_TARGET property
        
        currently an edit target
        
        Supported operations:
            getattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.EDIT_TARGET)
        _value = cast(int, value)
        return _value

    @property
    def edit_target(self) -> int:
        """EDIT_TARGET property
        
        currently an edit target
        
        Supported operations:
            getattr
        Datatype:
            Boolean, scalar
        
        Note: both 'edit_target' and 'EDIT_TARGET' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.EDIT_TARGET)
        _value = cast(int, value)
        return _value

    @property
    def PROJECT_MASK(self) -> int:
        """PROJECT_MASK property
        
        object project mask
        
        Supported operations:
            getattr, setattr
        Datatype:
            64bit integer, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.PROJECT_MASK)
        _value = cast(int, value)
        return _value

    @PROJECT_MASK.setter
    def PROJECT_MASK(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.PROJECT_MASK, value)

    @property
    def project_mask(self) -> int:
        """PROJECT_MASK property
        
        object project mask
        
        Supported operations:
            getattr, setattr
        Datatype:
            64bit integer, scalar
        
        Note: both 'project_mask' and 'PROJECT_MASK' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.PROJECT_MASK)
        _value = cast(int, value)
        return _value

    @project_mask.setter
    def project_mask(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.PROJECT_MASK, value)

    @property
    def HANDLES_ENABLED(self) -> int:
        """Control the display and use of EnSight click and go handles for an object
        
        EnSight allows for direct interaction with many objects via click and go handles.
        The handles allow things like annotations and viewports to be moved or resized.
        They allow for the adjustment of values for clip planes and palette dynamic ranges.
        In some situations, allowing the user to directly adjust these values can be
        undesirable.  Setting this attribute to zero disables display of and interaction
        with click and go handles for the specific object instance.
        
        """
        value = self.getattr(self._session.ensight.objs.enums.HANDLES_ENABLED)
        _value = cast(int, value)
        return _value

    @HANDLES_ENABLED.setter
    def HANDLES_ENABLED(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.HANDLES_ENABLED, value)

    @property
    def handles_enabled(self) -> int:
        """Control the display and use of EnSight click and go handles for an object
        
        EnSight allows for direct interaction with many objects via click and go handles.
        The handles allow things like annotations and viewports to be moved or resized.
        They allow for the adjustment of values for clip planes and palette dynamic ranges.
        In some situations, allowing the user to directly adjust these values can be
        undesirable.  Setting this attribute to zero disables display of and interaction
        with click and go handles for the specific object instance.
        
        Note: both 'handles_enabled' and 'HANDLES_ENABLED' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.HANDLES_ENABLED)
        _value = cast(int, value)
        return _value

    @handles_enabled.setter
    def handles_enabled(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.HANDLES_ENABLED, value)

    @property
    def PAGE_DETAILS(self) -> List[dict]:
        """PAGE_DETAILS property
        
        flipbook page information
        
        Supported operations:
            getattr
        Datatype:
            List of dictionaries, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.PAGE_DETAILS)
        _value = cast(List[dict], value)
        return _value

    @property
    def page_details(self) -> List[dict]:
        """PAGE_DETAILS property
        
        flipbook page information
        
        Supported operations:
            getattr
        Datatype:
            List of dictionaries, scalar
        
        Note: both 'page_details' and 'PAGE_DETAILS' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.PAGE_DETAILS)
        _value = cast(List[dict], value)
        return _value



"""ens_polyline module

The ens_polyline module provides a proxy interface to EnSight ENS_POLYLINE instances

"""
from ansys.pyensight.core.session import Session
from ansys.pyensight.core.ensobj import ENSOBJ
from ansys.pyensight.core import ensobjlist
from typing import Any, Dict, List, Type, Union, Optional, Tuple, TYPE_CHECKING, cast

if TYPE_CHECKING:
    from ansys.api.pyensight.ensight_api import ENS_VAR, ENS_ANNOT, ENS_PALETTE, ENS_PART, ENS_SOURCE, ENS_CASE, ENS_QUERY, ENS_GROUP, ENS_TOOL, ENS_TEXTURE, ENS_VPORT, ENS_PLOTTER, ENS_FRAME, ENS_PROBE, ENS_FLIPBOOK, ENS_SCENE, ENS_LPART, ENS_STATE, ens_emitterobj

class ENS_POLYLINE(ENSOBJ):
    """This class acts as a proxy for the EnSight Python class ensight.objs.ENS_POLYLINE

    Args:
        \*args:
            Superclass (ENSOBJ) arguments
        \**kwargs:
            Superclass (ENSOBJ) keyword arguments

    """

    def __init__(self, *args, **kwargs) -> None:
        super().__init__(*args, **kwargs)
        self._update_attr_list(self._session, self._objid)

    @classmethod
    def _update_attr_list(cls, session: 'Session', id: int) -> None:
        if hasattr(cls, 'attr_list'):
            return
        cmd = session.remote_obj(id) + '.__ids__'
        cls.attr_list = session.cmd(cmd)

    @property
    def objid(self) -> int:  # noqa: N802
        """
        Return the EnSight object proxy ID (__OBJID__).
        """
        return self._objid

    def attrgroupinfo(self, *args, **kwargs) -> Any:
        """Get information about GUI groups for object attributes

        """
        arg_obj = f"{self._remote_obj()}"
        arg_list: List[str] = []
        for arg in args:
            arg_list.append(arg.__repr__())
        for key, value in kwargs.items():
            arg_list.append(f"{key}={value.__repr__()}")
        arg_string = ",".join(arg_list)
        cmd = f"{arg_obj}.attrgroupinfo({arg_string})"
        return self._session.cmd(cmd)

    def interpolate(self, *args, **kwargs) -> Any:
        """Interpolate polyline points

        """
        arg_obj = f"{self._remote_obj()}"
        arg_list: List[str] = []
        for arg in args:
            arg_list.append(arg.__repr__())
        for key, value in kwargs.items():
            arg_list.append(f"{key}={value.__repr__()}")
        arg_string = ",".join(arg_list)
        cmd = f"{arg_obj}.interpolate({arg_string})"
        return self._session.cmd(cmd)

    def createpolyline(self, *args, **kwargs) -> Any:
        """Create a new polyline object

        """
        arg_obj = f"{self._remote_obj()}"
        arg_list: List[str] = []
        for arg in args:
            arg_list.append(arg.__repr__())
        for key, value in kwargs.items():
            arg_list.append(f"{key}={value.__repr__()}")
        arg_string = ",".join(arg_list)
        cmd = f"{arg_obj}.createpolyline({arg_string})"
        return self._session.cmd(cmd)

    @property
    def METADATA(self) -> Dict[Any, Any]:
        """METADATA property
        
        metadata
        
        Supported operations:
            getattr
        Datatype:
            CEI Metadata, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.METADATA)
        _value = cast(Dict[Any, Any], value)
        return _value

    @property
    def metadata(self) -> Dict[Any, Any]:
        """METADATA property
        
        metadata
        
        Supported operations:
            getattr
        Datatype:
            CEI Metadata, scalar
        
        Note: both 'metadata' and 'METADATA' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.METADATA)
        _value = cast(Dict[Any, Any], value)
        return _value

    @property
    def UUID(self) -> str:
        """UUID property
        
        universal unique id
        
        Supported operations:
            getattr
        Datatype:
            String, 37 characters maximum
        
        """
        value = self.getattr(self._session.ensight.objs.enums.UUID)
        _value = cast(str, value)
        return _value

    @property
    def uuid(self) -> str:
        """UUID property
        
        universal unique id
        
        Supported operations:
            getattr
        Datatype:
            String, 37 characters maximum
        
        Note: both 'uuid' and 'UUID' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.UUID)
        _value = cast(str, value)
        return _value

    @property
    def EDIT_TARGET(self) -> int:
        """EDIT_TARGET property
        
        currently an edit target
        
        Supported operations:
            getattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.EDIT_TARGET)
        _value = cast(int, value)
        return _value

    @property
    def edit_target(self) -> int:
        """EDIT_TARGET property
        
        currently an edit target
        
        Supported operations:
            getattr
        Datatype:
            Boolean, scalar
        
        Note: both 'edit_target' and 'EDIT_TARGET' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.EDIT_TARGET)
        _value = cast(int, value)
        return _value

    @property
    def PROJECT_MASK(self) -> int:
        """PROJECT_MASK property
        
        object project mask
        
        Supported operations:
            getattr, setattr
        Datatype:
            64bit integer, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.PROJECT_MASK)
        _value = cast(int, value)
        return _value

    @PROJECT_MASK.setter
    def PROJECT_MASK(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.PROJECT_MASK, value)

    @property
    def project_mask(self) -> int:
        """PROJECT_MASK property
        
        object project mask
        
        Supported operations:
            getattr, setattr
        Datatype:
            64bit integer, scalar
        
        Note: both 'project_mask' and 'PROJECT_MASK' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.PROJECT_MASK)
        _value = cast(int, value)
        return _value

    @project_mask.setter
    def project_mask(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.PROJECT_MASK, value)

    @property
    def HANDLES_ENABLED(self) -> int:
        """Control the display and use of EnSight click and go handles for an object
        
        EnSight allows for direct interaction with many objects via click and go handles.
        The handles allow things like annotations and viewports to be moved or resized.
        They allow for the adjustment of values for clip planes and palette dynamic ranges.
        In some situations, allowing the user to directly adjust these values can be
        undesirable.  Setting this attribute to zero disables display of and interaction
        with click and go handles for the specific object instance.
        
        """
        value = self.getattr(self._session.ensight.objs.enums.HANDLES_ENABLED)
        _value = cast(int, value)
        return _value

    @HANDLES_ENABLED.setter
    def HANDLES_ENABLED(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.HANDLES_ENABLED, value)

    @property
    def handles_enabled(self) -> int:
        """Control the display and use of EnSight click and go handles for an object
        
        EnSight allows for direct interaction with many objects via click and go handles.
        The handles allow things like annotations and viewports to be moved or resized.
        They allow for the adjustment of values for clip planes and palette dynamic ranges.
        In some situations, allowing the user to directly adjust these values can be
        undesirable.  Setting this attribute to zero disables display of and interaction
        with click and go handles for the specific object instance.
        
        Note: both 'handles_enabled' and 'HANDLES_ENABLED' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.HANDLES_ENABLED)
        _value = cast(int, value)
        return _value

    @handles_enabled.setter
    def handles_enabled(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.HANDLES_ENABLED, value)

    @property
    def DESCRIPTION(self) -> str:
        """DESCRIPTION property
        
        description
        
        Supported operations:
            getattr, setattr
        Datatype:
            String, 80 characters maximum
        
        """
        value = self.getattr(self._session.ensight.objs.enums.DESCRIPTION)
        _value = cast(str, value)
        return _value

    @DESCRIPTION.setter
    def DESCRIPTION(self, value: str) -> None:
        self.setattr(self._session.ensight.objs.enums.DESCRIPTION, value)

    @property
    def description(self) -> str:
        """DESCRIPTION property
        
        description
        
        Supported operations:
            getattr, setattr
        Datatype:
            String, 80 characters maximum
        
        Note: both 'description' and 'DESCRIPTION' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.DESCRIPTION)
        _value = cast(str, value)
        return _value

    @description.setter
    def description(self, value: str) -> None:
        self.setattr(self._session.ensight.objs.enums.DESCRIPTION, value)

    @property
    def ID(self) -> int:
        """ID property
        
        ID
        
        Supported operations:
            getattr
        Datatype:
            Integer, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.ID)
        _value = cast(int, value)
        return _value

    @property
    def id(self) -> int:
        """ID property
        
        ID
        
        Supported operations:
            getattr
        Datatype:
            Integer, scalar
        
        Note: both 'id' and 'ID' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.ID)
        _value = cast(int, value)
        return _value

    @property
    def SELECTED(self) -> int:
        """SELECTED property
        
        selected
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.SELECTED)
        _value = cast(int, value)
        return _value

    @SELECTED.setter
    def SELECTED(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.SELECTED, value)

    @property
    def selected(self) -> int:
        """SELECTED property
        
        selected
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        Note: both 'selected' and 'SELECTED' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.SELECTED)
        _value = cast(int, value)
        return _value

    @selected.setter
    def selected(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.SELECTED, value)

    @property
    def COLOR(self) -> List[float]:
        """COLOR property
        
        color
        
        Supported operations:
            getattr, setattr
        Datatype:
            Color RGB, 3 element array
        
        """
        value = self.getattr(self._session.ensight.objs.enums.COLOR)
        _value = cast(List[float], value)
        return _value

    @COLOR.setter
    def COLOR(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.COLOR, value)

    @property
    def color(self) -> List[float]:
        """COLOR property
        
        color
        
        Supported operations:
            getattr, setattr
        Datatype:
            Color RGB, 3 element array
        
        Note: both 'color' and 'COLOR' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.COLOR)
        _value = cast(List[float], value)
        return _value

    @color.setter
    def color(self, value: List[float]) -> None:
        self.setattr(self._session.ensight.objs.enums.COLOR, value)

    @property
    def VISIBLE(self) -> int:
        """VISIBLE property
        
        line visible
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.VISIBLE)
        _value = cast(int, value)
        return _value

    @VISIBLE.setter
    def VISIBLE(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.VISIBLE, value)

    @property
    def visible(self) -> int:
        """VISIBLE property
        
        line visible
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        Note: both 'visible' and 'VISIBLE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.VISIBLE)
        _value = cast(int, value)
        return _value

    @visible.setter
    def visible(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.VISIBLE, value)

    @property
    def POINTVISIBLE(self) -> int:
        """POINTVISIBLE property
        
        points visible
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.POINTVISIBLE)
        _value = cast(int, value)
        return _value

    @POINTVISIBLE.setter
    def POINTVISIBLE(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.POINTVISIBLE, value)

    @property
    def pointvisible(self) -> int:
        """POINTVISIBLE property
        
        points visible
        
        Supported operations:
            getattr, setattr
        Datatype:
            Boolean, scalar
        
        Note: both 'pointvisible' and 'POINTVISIBLE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.POINTVISIBLE)
        _value = cast(int, value)
        return _value

    @pointvisible.setter
    def pointvisible(self, value: int) -> None:
        self.setattr(self._session.ensight.objs.enums.POINTVISIBLE, value)

    @property
    def POINTSIZE(self) -> float:
        """POINTSIZE property
        
        point size
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.POINTSIZE)
        _value = cast(float, value)
        return _value

    @POINTSIZE.setter
    def POINTSIZE(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.POINTSIZE, value)

    @property
    def pointsize(self) -> float:
        """POINTSIZE property
        
        point size
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        
        Note: both 'pointsize' and 'POINTSIZE' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.POINTSIZE)
        _value = cast(float, value)
        return _value

    @pointsize.setter
    def pointsize(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.POINTSIZE, value)

    @property
    def LINEWIDTH(self) -> float:
        """LINEWIDTH property
        
        line width
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.LINEWIDTH)
        _value = cast(float, value)
        return _value

    @LINEWIDTH.setter
    def LINEWIDTH(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.LINEWIDTH, value)

    @property
    def linewidth(self) -> float:
        """LINEWIDTH property
        
        line width
        
        Supported operations:
            getattr, setattr
        Datatype:
            Float, scalar
        
        Note: both 'linewidth' and 'LINEWIDTH' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.LINEWIDTH)
        _value = cast(float, value)
        return _value

    @linewidth.setter
    def linewidth(self, value: float) -> None:
        self.setattr(self._session.ensight.objs.enums.LINEWIDTH, value)

    @property
    def NUMCONTROLPOINTS(self) -> int:
        """NUMCONTROLPOINTS property
        
        number of control points
        
        Supported operations:
            getattr
        Datatype:
            Integer, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.NUMCONTROLPOINTS)
        _value = cast(int, value)
        return _value

    @property
    def numcontrolpoints(self) -> int:
        """NUMCONTROLPOINTS property
        
        number of control points
        
        Supported operations:
            getattr
        Datatype:
            Integer, scalar
        
        Note: both 'numcontrolpoints' and 'NUMCONTROLPOINTS' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.NUMCONTROLPOINTS)
        _value = cast(int, value)
        return _value

    @property
    def CONTROLPOINTS(self) -> object:
        """CONTROLPOINTS property
        
        control points
        
        Supported operations:
            getattr
        Datatype:
            EnSight Object, scalar
        
        """
        value = self.getattr(self._session.ensight.objs.enums.CONTROLPOINTS)
        _value = cast(object, value)
        return _value

    @property
    def controlpoints(self) -> object:
        """CONTROLPOINTS property
        
        control points
        
        Supported operations:
            getattr
        Datatype:
            EnSight Object, scalar
        
        Note: both 'controlpoints' and 'CONTROLPOINTS' property names are supported.
        """
        value = self.getattr(self._session.ensight.objs.enums.CONTROLPOINTS)
        _value = cast(object, value)
        return _value
